/**
* @author Dirk Nordmann
* @date   14.01.2002
*/
package xml2rtf.rtf;

import util.*;
import img2wmf.*;
import java.io.*;
import xml2rtf.xml.*;

public class RtfImg 
{
  private String src;
  private int width;
  private int height;

  /**
  * Constructor
  */
  public RtfImg()
  {
    this.setSrc(null);
    this.setWidth("-1");
    this.setHeight("-1");
  }

  /**
  * Sets the source for this image-tag.
  * @param newSrc
  */
  public void setSrc(String newSrc) 
  {
    this.src = newSrc;
  }
  
  /**
  * Returns the source of this image-tag.
  * @return String
  */
  public String getSrc() 
  {
    return this.src;
  }
  
  /**
  * Sets the height for this image-tag.
  * @param newHeight
  */
  public void setHeight(String newHeight) 
  {
    if (newHeight != null)
      this.height = Integer.parseInt(newHeight);
  }
  
  /**
  * Returns the height of this image-tag.
  * @return int
  */
  public int getHeight() 
  {
    return this.height;
  }
  
  /**
  * Sets the width for this image-tag.
  * @param newWidth
  */
  public void setWidth(String newWidth) 
  {
    if (newWidth != null)
      this.width = Integer.parseInt(newWidth);
  }
  
  /**
  * Returns the width of this image-tag.
  * @return int
  */
  public int getWidth() 
  {
    return this.width;
  }
  
  /**
  * Processes RTF representation of picture:
  *   - Convert picture from GIF/JPG to WMF.
  *   - Build RTF-section (\\pict and \\picdata with hex-conversion of WMF).
  * @param   rtfgenerator	RTF-Generator Object
  * @return  String			  RTF-representation of ressource
  */
  public String process(RtfGenerator rtfgenerator)
  {
    XmlReader _input = rtfgenerator.getInput(); 
    RtfWriter _output = rtfgenerator.getOutput();
    String filename = FilePathUtility.getOSFileName(_input.getFilePath() + File.separator + this.getSrc());
    if (new File(filename).exists()) {
      String fileext = FilePathUtility.getFileExtension(filename).toLowerCase();
      if (fileext.equals(".jpg") || fileext.equals(".jpeg"))
        return new JpegToWMF(filename,this.getWidth(),this.getHeight()).getRtf();
      else if (fileext.equals(".gif"))
        return "";
      else      
        // return new ImageToWMF(filename,this.getWidth(),this.getHeight()).getRtf();
        return "";
    }
    else { 
     	System.out.println("*****[RtfImg.process]: FEHLER -- Abbildung '" + filename + "' nicht gefunden! *****");
     	return "{\\f1\\fs18" + _output.getColor("red") + _output.getBackgroundColor("yellow") + " [FEHLER: Abbildung {\\i\\ul\\b " + this.getSrc() + "} nicht gefunden!]\\par}";
    }
  }
}